package VMOMI::InternetScsiSnsDiscoveryMethod;
use parent 'VMOMI::SimpleType';

use strict;
use warnings;

1;
